@@ -31,13 +31,21 @@ module Network.MPD.Applicative (
 
 -- * Reflection
 , module Network.MPD.Applicative.Reflection
+
+-- * Mounting
+, module Network.MPD.Applicative.Mount
+
+-- * Client-to-client
+, module Network.MPD.Applicative.ClientToClient
 ) where
 
 import Network.MPD.Applicative.Internal
 
+import Network.MPD.Applicative.ClientToClient
 import Network.MPD.Applicative.Connection
 import Network.MPD.Applicative.CurrentPlaylist
 import Network.MPD.Applicative.Database
+import Network.MPD.Applicative.Mount
 import Network.MPD.Applicative.Output
 import Network.MPD.Applicative.PlaybackControl
 import Network.MPD.Applicative.PlaybackOptions
