@@ -71,9 +71,10 @@ clear = Command emptyResponse ["clear"]
 delete :: Position -> Command ()
 delete pos = Command emptyResponse ["delete" <@> pos]
 
--- XXX: this does not exist in the monadic version
 -- | Delete a range of songs from the playlist.
-deleteRange :: (Position, Position) -> Command ()
+--
+-- @since 0.10.0.0
+deleteRange :: Range -> Command ()
 deleteRange range = Command emptyResponse ["delete" <@> range]
 
 -- | Delete song by id.
@@ -85,7 +86,9 @@ move :: Position -> Position -> Command ()
 move pos to = Command emptyResponse ["move" <@> pos <++> to]
 
 -- | Move a range of songs.
-moveRange :: (Position, Position) -> Position -> Command ()
+--
+-- @since 0.10.0.0
+moveRange :: Range -> Position -> Command ()
 moveRange range to = Command emptyResponse ["move" <@> range <++> to]
 
 -- | Move song id to position.
@@ -110,7 +113,9 @@ playlistInfo = playlist' "playlistinfo"
 
 -- | Like 'playlistInfo' but can restrict listing to a range
 -- of songs.
-playlistInfoRange :: Maybe (Position, Position) -> Command [Song]
+--
+-- @since 0.10.0.0
+playlistInfoRange :: Maybe Range -> Command [Song]
 playlistInfoRange = playlist' "playlistinfo"
 
 -- | Get song metadata for all items in the current playlist.
@@ -141,7 +146,9 @@ plChangesPosId ver = Command p ["plchangesposid" <@> ver]
              | otherwise = Left ""
 
 -- | Set the priority of the specified songs.
-prio :: Priority -> (Position, Position) -> Command ()
+--
+-- @since 0.10.0.0
+prio :: Priority -> Range -> Command ()
 prio p range = Command emptyResponse ["prio" <@> p <++> range]
 
 -- | Set priority by song id.
@@ -150,7 +157,9 @@ prioId p ids = Command emptyResponse ["prioid" <@> p <++> ids]
 
 -- | Shuffle the current playlist.
 -- Optionally restrict to a range of songs.
-shuffle :: Maybe (Position, Position) -> Command ()
+--
+-- @since 0.10.0.0
+shuffle :: Maybe Range -> Command ()
 shuffle mbRange = Command emptyResponse ["shuffle" <@> mbRange]
 
 -- | Swap songs by position.
@@ -171,6 +180,8 @@ clearTagId id' tags = Command emptyResponse ["cleartagid" <@> id' <++> tags]
 
 -- | Specify portion of song that shall be played.
 -- Both ends of the range are optional; omitting both plays everything.
+--
+-- Since MPD 0.19.
 rangeId :: Id -> (Maybe Double, Maybe Double) -> Command ()
 rangeId id' (mbStart, mbEnd) = Command emptyResponse ["rangeid " ++ show id' ++ " " ++ arg ]
   where arg = maybe "" show mbStart ++ ":" ++ maybe "" show mbEnd
