@@ -17,8 +17,10 @@ module Network.MPD.Commands.CurrentPlaylist
     , add
     , clear
     , delete
+    , deleteRange
     , deleteId
     , move
+    , moveRange
     , moveId
     , playlist
     , playlistFind
@@ -45,7 +47,7 @@ import           Network.MPD.Commands.Types
 import           Network.MPD.Core
 import           Network.MPD.Util
 
-import           Control.Monad.Error (throwError)
+import           Control.Monad.Except (throwError)
 
 -- | Like 'add', but returns a playlist id.
 addId :: MonadMPD m => Path -> Maybe Position -> m Id
@@ -63,6 +65,12 @@ clear = A.runCommand A.clear
 delete :: MonadMPD m => Position -> m ()
 delete = A.runCommand . A.delete
 
+-- | Remove a range of songs from the current playlist.
+--
+-- @since 0.10.0.0
+deleteRange :: MonadMPD m => Range -> m ()
+deleteRange = A.runCommand . A.deleteRange
+
 -- | Remove a song from the current playlist.
 deleteId :: MonadMPD m => Id -> m ()
 deleteId = A.runCommand . A.deleteId
@@ -71,6 +79,12 @@ deleteId = A.runCommand . A.deleteId
 move :: MonadMPD m => Position -> Position -> m ()
 move pos = A.runCommand . A.move pos
 
+-- | Move a range of songs to a given position in the current playlist.
+--
+-- @since 0.10.0.0
+moveRange :: MonadMPD m => Range -> Position -> m ()
+moveRange range = A.runCommand . A.moveRange range
+
 -- | Move a song from (songid) to (playlist index) in the playlist. If to is
 -- negative, it is relative to the current song in the playlist (if there is one).
 moveId :: MonadMPD m => Id -> Position -> m ()
@@ -97,7 +111,9 @@ playlistInfo :: MonadMPD m => Maybe Position -> m [Song]
 playlistInfo = A.runCommand . A.playlistInfo
 
 -- | Like 'playlistInfo' but can restrict to a range of songs.
-playlistInfoRange :: MonadMPD m => Maybe (Position, Position) -> m [Song]
+--
+-- @since 0.10.0.0
+playlistInfoRange :: MonadMPD m => Maybe Range -> m [Song]
 playlistInfoRange = A.runCommand . A.playlistInfoRange
 
 -- | Displays a list of songs in the playlist.
@@ -120,16 +136,20 @@ plChangesPosId :: MonadMPD m => Integer -> m [(Position, Id)]
 plChangesPosId = A.runCommand . A.plChangesPosId
 
 -- | Set the priority of the specified songs.
-prio :: MonadMPD m => Priority -> (Position, Position) -> m ()
+--
+-- @since 0.10.0.0
+prio :: MonadMPD m => Priority -> Range -> m ()
 prio p = A.runCommand . A.prio p
 
 -- | Set priority by song id.
 prioId :: MonadMPD m => Priority -> Id -> m ()
 prioId p = A.runCommand . A.prioId p
 
--- | Shuffle the playlist.
-shuffle :: MonadMPD m => Maybe (Position, Position) -- ^ Optional range (start, end)
-        -> m ()
+-- | Shuffle the current playlist.
+-- Optionally restrict to a range of songs.
+--
+-- @since 0.10.0.0
+shuffle :: MonadMPD m => Maybe Range -> m ()
 shuffle = A.runCommand . A.shuffle
 
 -- | Swap the positions of two songs.
