@@ -15,6 +15,7 @@ Audio output devices.
 module Network.MPD.Commands.Output
     ( disableOutput
     , enableOutput
+    , toggleOutput
     , outputs
     ) where
 
@@ -31,6 +32,10 @@ disableOutput = A.runCommand . A.disableOutput
 enableOutput :: MonadMPD m => Int -> m ()
 enableOutput = A.runCommand . A.enableOutput
 
+-- | Toggle output device.
+toggleOutput :: MonadMPD m => Int -> m ()
+toggleOutput = A.runCommand . A.toggleOutput
+
 -- | Retrieve information for all output devices.
 outputs :: MonadMPD m => m [Device]
 outputs = A.runCommand A.outputs
